pub struct CommandSpec {
pub argv: Vec<String>,
pub cwd: Option<String>,
pub env: BTreeMap<String, SecretRef>,
pub shell: bool,
pub timeout_ms: u64,
pub memory_bytes: u64,
pub cpu_millis: u64,
pub max_processes: u32,
pub network: CommandNetworkPolicy,
pub disk_bytes: u64,
pub max_output_bytes: usize,
}Fields
argv: Vec<String>cwd: Option<String>env: BTreeMap<String, SecretRef>shell: booltimeout_ms: u64memory_bytes: u64cpu_millis: u64max_processes: u32network: CommandNetworkPolicyWhether provider-side egress is denied or permitted for this command. Providers must reject unsupported policy rather than silently ignore it.
disk_bytes: u64Maximum additional writable bytes for the command sandbox.
max_output_bytes: usizeTrait Implementations
Sourceimpl Clone for CommandSpec
impl Clone for CommandSpec
Sourcefn clone(&self) -> CommandSpec
fn clone(&self) -> CommandSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandSpec
impl Debug for CommandSpec
Sourceimpl<'de> Deserialize<'de> for CommandSpec
impl<'de> Deserialize<'de> for CommandSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CommandSpec
Sourceimpl PartialEq for CommandSpec
impl PartialEq for CommandSpec
Sourceimpl Serialize for CommandSpec
impl Serialize for CommandSpec
impl StructuralPartialEq for CommandSpec