pub struct EnvironmentMetadataSnapshot {Show 14 fields
pub version: u64,
pub computers: Vec<ComputerRecord>,
pub spaces: Vec<SpaceRecord>,
pub sandboxes: Vec<SandboxRecord>,
pub snapshots: Vec<SnapshotRecord>,
pub templates: Vec<TemplateVersionRecord>,
pub grants: Vec<SpaceGrant>,
pub sessions: Vec<SpaceCollaborationSession>,
pub tickets: Vec<SpaceAccessTicketRecord>,
pub leases: Vec<SpaceWriteLease>,
pub fencing_tokens: BTreeMap<String, u64>,
pub delegations: Vec<DelegationRecord>,
pub change_sets: Vec<SpaceChangeSetRecord>,
pub idempotency: Vec<EnvironmentIdempotencyRecord>,
}Expand description
Durable metadata snapshot for one tenant/project scope.
Provider bytes and credentials are deliberately absent. Repositories may store each collection in a dedicated table while exposing one CAS unit to the application service so fencing and revision changes commit together.
Fields
version: u64computers: Vec<ComputerRecord>spaces: Vec<SpaceRecord>sandboxes: Vec<SandboxRecord>snapshots: Vec<SnapshotRecord>templates: Vec<TemplateVersionRecord>grants: Vec<SpaceGrant>sessions: Vec<SpaceCollaborationSession>tickets: Vec<SpaceAccessTicketRecord>leases: Vec<SpaceWriteLease>fencing_tokens: BTreeMap<String, u64>delegations: Vec<DelegationRecord>change_sets: Vec<SpaceChangeSetRecord>idempotency: Vec<EnvironmentIdempotencyRecord>Trait Implementations
Sourceimpl Clone for EnvironmentMetadataSnapshot
impl Clone for EnvironmentMetadataSnapshot
Sourcefn clone(&self) -> EnvironmentMetadataSnapshot
fn clone(&self) -> EnvironmentMetadataSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvironmentMetadataSnapshot
impl Debug for EnvironmentMetadataSnapshot
Sourceimpl Default for EnvironmentMetadataSnapshot
impl Default for EnvironmentMetadataSnapshot
Sourcefn default() -> EnvironmentMetadataSnapshot
fn default() -> EnvironmentMetadataSnapshot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EnvironmentMetadataSnapshot
impl<'de> Deserialize<'de> for EnvironmentMetadataSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EnvironmentMetadataSnapshot
impl StructuralPartialEq for EnvironmentMetadataSnapshot