pub struct StoreComputerCommandRequest {
pub scope: ResourceScope,
pub idempotency_key_hash: String,
pub request_hash: String,
pub command: ComputerCommandResource,
}Expand description
Durable, scope-qualified command creation input owned by the Workspace command repository. Only hashes of caller idempotency material cross the persistence boundary.
Fields
scope: ResourceScopeidempotency_key_hash: Stringrequest_hash: Stringcommand: ComputerCommandResourceTrait Implementations
Sourceimpl Clone for StoreComputerCommandRequest
impl Clone for StoreComputerCommandRequest
Sourcefn clone(&self) -> StoreComputerCommandRequest
fn clone(&self) -> StoreComputerCommandRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoreComputerCommandRequest
impl Debug for StoreComputerCommandRequest
impl Eq for StoreComputerCommandRequest
impl StructuralPartialEq for StoreComputerCommandRequest